## CHANGELOG

### 0.11.0 - 2020-04-04

 - Improve bool deserialization

 - Fix Union deserialization

 - Create support for use `__get_dynamic_type__` function on annotations types

 - Remove unused parameter on OrjsonDefaultTypes.default_function

 - Improve dataclasses.asdict function

 - Remove dataclass recreation on decorator

 - Fix pyflakes

### 0.10.2 - 2020-02-27

 - Fix serializers

### 0.10.1 - 2020-02-26

 - Fix deserialize_field function

### 0.10.0 - 2020-02-24

 - Add support for deserialize standard types

### 0.9.0 - 2019-10-23

 - Improve string and integer schemas

 - Improve mypy

### 0.8.1 - 2019-10-22

 - Add package typing support

### 0.8.0 - 2019-10-02

 - Pin orjson version

 - Fix typo on readme

 - Improve jsondaora decorator

 - Add devtools git submodule

### 0.7.0 - 2019-09-27

 - Create changelog manager
